Learn R Programming

DSLite (version 1.2.0)

getDSLiteData: Get data value from DSLite connection(s)

Description

Get the data value corresponding to the variable with the symbol name from the DSLiteServer associated to the DSConnection-class object(s). Can be useful when developping a DataSHIELD package.

Usage

getDSLiteData(conns, symbol)

Arguments

conns
symbol

Symbol name identifying the variable in the DSLiteServer's "server-side" environment(s).

Value

The data value or a list of values depending on the connections parameter. The value is NA when the connection object is not of class DSLiteConnection-class.

Examples

Run this code
# NOT RUN {
{
# DataSHIELD login
logindata <- setupCNSIMTest()
conns <- datashield.login(logindata, assign=TRUE)
# retrieve symbol D value from each DataSHIELD connections
getDSLiteData(conns, "D")
# retrieve symbol D value from a specific DataSHIELD connection
getDSLiteData(conns$sim1, "D")
}

# }

Run the code above in your browser using DataLab